# Copyright (c) 2004-2006 Bethel University. All rights reserved.
# See also gpl.txt
from Globals import package_home

from Products.Silva.install import add_fss_directory_view
from Products.Silva import roleinfo

from CustomAutoTOC import CustomAutoTOC,CustomAutoTOCPolicy

def is_installed(root):
    return hasattr(root.service_views, 'SilvaCustomAutoTOC')

def install(root):     
    # create the core views from filesystem
    add_fss_directory_view(root.service_views, 'SilvaCustomAutoTOC', __file__, 'views')
    
    # also register views
    registerViews(root.service_view_registry)

    # add or update service metadata
    configureMetadata(root)
    
    configureContainerPolicies(root)

    #make cautotoc addable from the silva root
    addable = 'Silva Custom AutoTOC'
    new_addables = root.get_silva_addables_allowed_in_publication()
    if addable not in new_addables:
        new_addables.append(addable)
        root.set_silva_addables_allowed_in_publication(new_addables)
    root.manage_permission('Add Silva Custom AutoTOCs',
                           roleinfo.AUTHOR_ROLES)

def uninstall(root):
    unregisterViews(root.service_view_registry)
    root.service_views.manage_delObjects(['SilvaCustomAutoTOC'])
    unconfigureMetadata(root)
    unconfigureContainerPolicies(root)    

    #make cautotoc addable from the silva root
    addable = 'Silva Custom AutoTOC'
    new_addables = root.get_silva_addables_allowed_in_publication()
    new_addables = [ a for a in new_addables if a != addable ]
    root.set_silva_addables_allowed_in_publication(new_addables)

def configureMetadata(root):
    root.service_metadata.addTypeMapping('Silva Custom AutoTOC',
                                         ['silva-content', 'silva-extra'])
def unconfigureMetadata(root):
    #XXX this doesn't "really" remove it,
    root.service_metadata.removeTypeMapping('Silva Custom AutoTOC',
                                         ['silva-content', 'silva-extra'])
    #this "really" removes it
    from Products.SilvaMetadata.Configuration import TypeMapping
    ctm = getattr(root.service_metadata,TypeMapping)
    ctm.manage_delObjects(['Silva Custom AutoTOC'])

def registerViews(reg):
    """Register core views on registry.
    """
    # edit
    reg.register('edit', 'Silva Custom AutoTOC', 
                 ['edit', 'Content', 'CustomAutoTOC'])
    reg.register('public', 'Silva Custom AutoTOC', ['public', 'CustomAutoTOC', 'view'])
    reg.register('add', 'Silva Custom AutoTOC', ['add', 'CustomAutoTOC'])
    reg.register('preview', 'Silva Custom AutoTOC', ['public', 'CustomAutoTOC', 'preview'])

def unregisterViews(reg):
    meta_type = 'Silva Custom AutoTOC'
    reg.unregister('edit', meta_type)
    reg.unregister('public',meta_type)
    reg.unregister('add', meta_type)

def configureContainerPolicies(root):
    cpr = root.service_containerpolicy
    cpr.register(CustomAutoTOC.meta_type, CustomAutoTOCPolicy, 0)

def unconfigureContainerPolicies(root):
    cpr = root.service_containerpolicy
    cpr.unregister(CustomAutoTOC.meta_type)



if __name__ == '__main__':
    print """This module is not an installer. You don't have to run it."""
